@@ -3,15 +3,15 @@ import pytest
 
 
 @pytest.mark.parametrize(
-    'gnupghome',
+    "gnupghome",
     [True, False],
-    ids=['gnupghome-set', 'gnupghome-unset'],
+    ids=["gnupghome-set", "gnupghome-unset"],
 )
-@pytest.mark.parametrize('param', ['all', 'gnupg'])
+@pytest.mark.parametrize("param", ["all", "gnupg"])
 def test_relative_path(runner, paths, gnupghome, param):
     """Test translate_to_relative"""
 
-    alt_gnupghome = 'alt/gnupghome'
+    alt_gnupghome = "alt/gnupghome"
     env_gnupghome = paths.work.join(alt_gnupghome)
 
     script = f"""
@@ -22,13 +22,13 @@ def test_relative_path(runner, paths, gnupghome, param):
 
     env = {}
     if gnupghome:
-        env['GNUPGHOME'] = env_gnupghome
+        env["GNUPGHOME"] = env_gnupghome
 
-    expected = alt_gnupghome if gnupghome else '.gnupg'
-    if param == 'all':
-        expected = f'.ssh {expected}'
+    expected = alt_gnupghome if gnupghome else ".gnupg"
+    if param == "all":
+        expected = f".ssh {expected}"
 
-    run = runner(command=['bash'], inp=script, env=env)
+    run = runner(command=["bash"], inp=script, env=env)
     assert run.success
-    assert run.err == ''
+    assert run.err == ""
     assert run.out.strip() == expected
