@@ -3,7 +3,7 @@ import pytest
 
 
 @pytest.mark.parametrize(
-    'base,full_path,expected',
+    "base,full_path,expected",
     [
         ("/A/B/C", "/A", "../.."),
         ("/A/B/C", "/A/B", ".."),
@@ -25,7 +25,7 @@ def test_relative_path(runner, paths, base, full_path, expected):
         relative_path "{base}" "{full_path}"
     """
 
-    run = runner(command=['bash'], inp=script)
+    run = runner(command=["bash"], inp=script)
     assert run.success
-    assert run.err == ''
+    assert run.err == ""
     assert run.out.strip() == expected
